Core API Basics — SQLAlchemy 1.2 Documentation

Release: 1.2.6 | Release Date: March 30, 2018

# SQLAlchemy 1.2 Documentation

# Core API Basics

- Events
  - Event Registration
  - Named Argument Styles
  - Targets
  - Modifiers
  - Event Reference
  - API Reference
- Runtime Inspection API
  - Available Inspection Targets
- Deprecated Event Interfaces
  - Execution, Connection and Cursor Events
  - Connection Pool Events
- Core Exceptions
- Core Internals